@@ -1,23 +1,21 @@
 /*
- * $Id$
- *
- * DEBUG: section 54    Interprocess Communication
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/* DEBUG: section 54    Interprocess Communication */
+
 #include "squid.h"
 #include "base/TextException.h"
 #include "CpuAffinitySet.h"
 #include "Debug.h"
 #include "util.h"
 
-#if HAVE_ERRNO_H
-#include <errno.h>
-#endif
-#if HAVE_STRING_H
-#include <string.h>
-#endif
-
+#include <cerrno>
+#include <cstring>
 
 CpuAffinitySet::CpuAffinitySet()
 {
@@ -39,7 +37,7 @@ CpuAffinitySet::apply()
     } else {
         cpu_set_t cpuSet;
         memcpy(&cpuSet, &theCpuSet, sizeof(cpuSet));
-        CPU_AND(&cpuSet, &cpuSet, &theOrigCpuSet);
+        (void) CPU_AND(&cpuSet, &cpuSet, &theOrigCpuSet);
         if (CPU_COUNT(&cpuSet) <= 0) {
             debugs(54, DBG_IMPORTANT, "ERROR: invalid CPU affinity for process "
                    "PID " << getpid() << ", may be caused by an invalid core in "
@@ -68,8 +66,11 @@ CpuAffinitySet::undo()
 }
 
 bool
-CpuAffinitySet::applied() const
+CpuAffinitySet::applied()
 {
+    // NOTE: cannot be const.
+    // According to CPU_SET(3) and, apparently, on some systems (e.g.,
+    // OpenSuSE 10.3) CPU_COUNT macro expects a non-const argument.
     return (CPU_COUNT(&theOrigCpuSet) > 0);
 }
 
@@ -78,3 +79,4 @@ CpuAffinitySet::set(const cpu_set_t &aCpuSet)
 {
     memcpy(&theCpuSet, &aCpuSet, sizeof(theCpuSet));
 }
+
