@@ -1,45 +1,24 @@
 /*
- * DEBUG: section 42    ICMP Pinger program
- * AUTHOR: Duane Wessels, Amos Jeffries
- *
- * SQUID Web Proxy Cache          http://www.squid-cache.org/
- * ----------------------------------------------------------
- *
- *  Squid is the result of efforts by numerous individuals from
- *  the Internet community; see the CONTRIBUTORS file for full
- *  details.   Many organizations have provided support for Squid's
- *  development; see the SPONSORS file for full details.  Squid is
- *  Copyrighted (C) 2001 by the Regents of the University of
- *  California; see the COPYRIGHT file for full details.  Squid
- *  incorporates software developed and/or copyrighted by other
- *  sources; see the CREDITS file for full details.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
+
+/* DEBUG: section 42    ICMP Pinger program */
+
 //#define SQUID_HELPER 1
 
 #include "squid.h"
 
 #if USE_ICMP
 
-#include "leakcheck.h"
-#include "SquidTime.h"
 #include "Debug.h"
 #include "Icmp6.h"
 #include "IcmpPinger.h"
+#include "leakcheck.h"
+#include "SquidTime.h"
 
 // Some system headers are only neeed internally here.
 // They should not be included via the header.
@@ -55,11 +34,11 @@ IcmpPacketType(uint8_t v)
 {
     // NP: LowPktStr is for codes 0-127
     static const char *icmp6LowPktStr[] = {
-        "ICMPv6 0",			// 0
-        "Destination Unreachable",	// 1 - RFC2463
-        "Packet Too Big", 		// 2 - RFC2463
-        "Time Exceeded",		// 3 - RFC2463
-        "Parameter Problem",		// 4 - RFC2463
+        "ICMPv6 0",         // 0
+        "Destination Unreachable",  // 1 - RFC2463
+        "Packet Too Big",       // 2 - RFC2463
+        "Time Exceeded",        // 3 - RFC2463
+        "Parameter Problem",        // 4 - RFC2463
     };
 
     // low codes 1-4 registered
@@ -68,32 +47,32 @@ IcmpPacketType(uint8_t v)
 
     // NP: HighPktStr is for codes 128-255
     static const char *icmp6HighPktStr[] = {
-        "Echo Request",					// 128 - RFC2463
-        "Echo Reply",					// 129 - RFC2463
-        "Multicast Listener Query",			// 130 - RFC2710
-        "Multicast Listener Report",			// 131 - RFC2710
-        "Multicast Listener Done",			// 132 - RFC2710
-        "Router Solicitation",				// 133 - RFC4861
-        "Router Advertisement",				// 134 - RFC4861
-        "Neighbor Solicitation",			// 135 - RFC4861
-        "Neighbor Advertisement",			// 136 - RFC4861
-        "Redirect Message",				// 137 - RFC4861
-        "Router Renumbering",				// 138 - Crawford
-        "ICMP Node Information Query",			// 139 - RFC4620
-        "ICMP Node Information Response",		// 140 - RFC4620
-        "Inverse Neighbor Discovery Solicitation",	// 141 - RFC3122
-        "Inverse Neighbor Discovery Advertisement",	// 142 - RFC3122
-        "Version 2 Multicast Listener Report",		// 143 - RFC3810
-        "Home Agent Address Discovery Request",		// 144 - RFC3775
-        "Home Agent Address Discovery Reply",		// 145 - RFC3775
-        "Mobile Prefix Solicitation",			// 146 - RFC3775
-        "Mobile Prefix Advertisement",			// 147 - RFC3775
-        "Certification Path Solicitation",		// 148 - RFC3971
-        "Certification Path Advertisement",		// 149 - RFC3971
-        "ICMP Experimental (150)",			// 150 - RFC4065
-        "Multicast Router Advertisement",		// 151 - RFC4286
-        "Multicast Router Solicitation",		// 152 - RFC4286
-        "Multicast Router Termination",			// 153 - [RFC4286]
+        "Echo Request",                 // 128 - RFC2463
+        "Echo Reply",                   // 129 - RFC2463
+        "Multicast Listener Query",         // 130 - RFC2710
+        "Multicast Listener Report",            // 131 - RFC2710
+        "Multicast Listener Done",          // 132 - RFC2710
+        "Router Solicitation",              // 133 - RFC4861
+        "Router Advertisement",             // 134 - RFC4861
+        "Neighbor Solicitation",            // 135 - RFC4861
+        "Neighbor Advertisement",           // 136 - RFC4861
+        "Redirect Message",             // 137 - RFC4861
+        "Router Renumbering",               // 138 - Crawford
+        "ICMP Node Information Query",          // 139 - RFC4620
+        "ICMP Node Information Response",       // 140 - RFC4620
+        "Inverse Neighbor Discovery Solicitation",  // 141 - RFC3122
+        "Inverse Neighbor Discovery Advertisement", // 142 - RFC3122
+        "Version 2 Multicast Listener Report",      // 143 - RFC3810
+        "Home Agent Address Discovery Request",     // 144 - RFC3775
+        "Home Agent Address Discovery Reply",       // 145 - RFC3775
+        "Mobile Prefix Solicitation",           // 146 - RFC3775
+        "Mobile Prefix Advertisement",          // 147 - RFC3775
+        "Certification Path Solicitation",      // 148 - RFC3971
+        "Certification Path Advertisement",     // 149 - RFC3971
+        "ICMP Experimental (150)",          // 150 - RFC4065
+        "Multicast Router Advertisement",       // 151 - RFC4286
+        "Multicast Router Solicitation",        // 152 - RFC4286
+        "Multicast Router Termination",         // 153 - [RFC4286]
     };
 
     // high codes 127-153 registered
@@ -184,7 +163,7 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
 
     icmp->icmp6_cksum = CheckSum((unsigned short *) icmp, icmp6_pktsize);
 
-    to.GetAddrInfo(S);
+    to.getAddrInfo(S);
     ((sockaddr_in6*)S->ai_addr)->sin6_port = 0;
 
     assert(icmp6_pktsize <= MAX_PKT6_SZ);
@@ -204,7 +183,7 @@ Icmp6::SendEcho(Ip::Address &to, int opcode, const char *payload, int len)
     debugs(42,9, HERE << "x=" << x);
 
     Log(to, 0, NULL, 0, 0);
-    to.FreeAddrInfo(S);
+    Ip::Address::FreeAddr(S);
 }
 
 /**
@@ -231,7 +210,7 @@ Icmp6::Recv(void)
         pkt = (char *)xmalloc(MAX_PKT6_SZ);
     }
 
-    preply.from.InitAddrInfo(from);
+    Ip::Address::InitAddr(from);
 
     n = recvfrom(icmp_sock,
                  (void *)pkt,
@@ -242,7 +221,7 @@ Icmp6::Recv(void)
 
     if (n <= 0) {
         debugs(42, DBG_CRITICAL, HERE << "Error when calling recvfrom() on ICMPv6 socket.");
-        Ip::Address::FreeAddrInfo(from);
+        Ip::Address::FreeAddr(from);
         return;
     }
 
@@ -263,32 +242,31 @@ Icmp6::Recv(void)
 // FIXME INET6 : The IPv6 Header (ip6_hdr) is not availble directly >:-(
 //
 // TTL still has to come from the IP header somewhere.
-//	still need to strip and process it properly.
-//	probably have to rely on RTT as given by timestamp in data sent and current.
+//  still need to strip and process it properly.
+//  probably have to rely on RTT as given by timestamp in data sent and current.
     /* IPv6 Header Structures (linux)
     struct ip6_hdr
 
     // fields (via simple define)
-    #define ip6_vfc		// N.A
-    #define ip6_flow	// N/A
-    #define ip6_plen	// payload length.
-    #define ip6_nxt		// expect to be type 0x3a - ICMPv6
-    #define ip6_hlim	// MAX hops  (always 64, but no guarantee)
-    #define ip6_hops	// HOPS!!!  (can it be true??)
+    #define ip6_vfc     // N.A
+    #define ip6_flow    // N/A
+    #define ip6_plen    // payload length.
+    #define ip6_nxt     // expect to be type 0x3a - ICMPv6
+    #define ip6_hlim    // MAX hops  (always 64, but no guarantee)
+    #define ip6_hops    // HOPS!!!  (can it be true??)
 
         ip = (struct ip6_hdr *) pkt;
-        pkt += sizeof(ip6_hdr);
+        NP: echo size needs to +sizeof(ip6_hdr);
 
     debugs(42, DBG_CRITICAL, HERE << "ip6_nxt=" << ip->ip6_nxt <<
-    		", ip6_plen=" << ip->ip6_plen <<
-    		", ip6_hlim=" << ip->ip6_hlim <<
-    		", ip6_hops=" << ip->ip6_hops	<<
-    		" ::: 40 == sizef(ip6_hdr) == " << sizeof(ip6_hdr)
+            ", ip6_plen=" << ip->ip6_plen <<
+            ", ip6_hlim=" << ip->ip6_hlim <<
+            ", ip6_hops=" << ip->ip6_hops   <<
+            " ::: 40 == sizef(ip6_hdr) == " << sizeof(ip6_hdr)
     );
     */
 
     icmp6header = (struct icmp6_hdr *) pkt;
-    pkt += sizeof(icmp6_hdr);
 
     if (icmp6header->icmp6_type != ICMP6_ECHO_REPLY) {
 
@@ -303,17 +281,17 @@ Icmp6::Recv(void)
             debugs(42, 8, HERE << preply.from << " said: " << icmp6header->icmp6_type << "/" << (int)icmp6header->icmp6_code << " " <<
                    IcmpPacketType(icmp6header->icmp6_type));
         }
-        preply.from.FreeAddrInfo(from);
+        Ip::Address::FreeAddr(from);
         return;
     }
 
     if (icmp6header->icmp6_id != icmp_ident) {
         debugs(42, 8, HERE << "dropping Icmp6 read. IDENT check failed. ident=='" << icmp_ident << "'=='" << icmp6header->icmp6_id << "'");
-        preply.from.FreeAddrInfo(from);
+        Ip::Address::FreeAddr(from);
         return;
     }
 
-    echo = (icmpEchoData *) pkt;
+    echo = (icmpEchoData *) (pkt + sizeof(icmp6_hdr));
 
     preply.opcode = echo->opcode;
 
@@ -324,7 +302,7 @@ Icmp6::Recv(void)
     /*
      * FIXME INET6: Without access to the IPv6-Hops header we must rely on the total RTT
      *      and could caculate the hops from that, but it produces some weird value mappings using ipHops
-     *	for now everything is 1 v6 hop away with variant RTT
+     *  for now everything is 1 v6 hop away with variant RTT
      * WANT:    preply.hops = ip->ip6_hops; // ipHops(ip->ip_hops);
      */
     preply.hops = 1;
@@ -346,7 +324,8 @@ Icmp6::Recv(void)
 
     /* send results of the lookup back to squid.*/
     control.SendResult(preply, (sizeof(pingerReplyData) - PINGER_PAYLOAD_SZ + preply.psize) );
-    preply.from.FreeAddrInfo(from);
+    Ip::Address::FreeAddr(from);
 }
 
 #endif /* USE_ICMP */
+
